@@ -140,19 +140,16 @@ class RosClient(Ros):
 
         return await_callback(self.forward_kinematics_async, **kwargs)
 
-    def plan_cartesian_motion(self, frames, base_link,
-                              ee_link, group, joint_names, joint_types,
-                              start_configuration, max_step, jump_threshold,
+    def plan_cartesian_motion(self,
+                              robot, frames, start_configuration,
+                              group, max_step, jump_threshold,
                               avoid_collisions, path_constraints,
                               attached_collision_meshes):
         kwargs = {}
+        kwargs['robot'] = robot
         kwargs['frames'] = frames
-        kwargs['base_link'] = base_link
-        kwargs['ee_link'] = ee_link
-        kwargs['group'] = group
-        kwargs['joint_names'] = joint_names
-        kwargs['joint_types'] = joint_types
         kwargs['start_configuration'] = start_configuration
+        kwargs['group'] = group
         kwargs['max_step'] = max_step
         kwargs['jump_threshold'] = jump_threshold
         kwargs['avoid_collisions'] = avoid_collisions
@@ -163,23 +160,19 @@ class RosClient(Ros):
 
         return await_callback(self.plan_cartesian_motion_async, **kwargs)
 
-    def plan_motion(self, goal_constraints, base_link, ee_link, group,
-                    joint_names, joint_types, start_configuration, path_constraints=None,
-                    trajectory_constraints=None, planner_id='',
-                    num_planning_attempts=8, allowed_planning_time=2.,
+    def plan_motion(self, robot, goal_constraints, start_configuration, group,
+                    path_constraints=None, trajectory_constraints=None,
+                    planner_id='', num_planning_attempts=8,
+                    allowed_planning_time=2.,
                     max_velocity_scaling_factor=1.,
                     max_acceleration_scaling_factor=1.,
                     attached_collision_meshes=None,
                     workspace_parameters=None):
-
         kwargs = {}
+        kwargs['robot'] = robot
         kwargs['goal_constraints'] = goal_constraints
-        kwargs['base_link'] = base_link
-        kwargs['ee_link'] = ee_link
-        kwargs['group'] = group
-        kwargs['joint_names'] = joint_names
-        kwargs['joint_types'] = joint_types
         kwargs['start_configuration'] = start_configuration
+        kwargs['group'] = group
         kwargs['path_constraints'] = path_constraints
         kwargs['trajectory_constraints'] = trajectory_constraints
         kwargs['planner_id'] = planner_id
