@@ -42,6 +42,9 @@ class Time(ROSmsg):
         self.secs = secs
         self.nsecs = nsecs
 
+    def seconds(self):
+        return self.secs + 1e-9 * self.nsecs
+
 
 class Header(ROSmsg):
     """http://docs.ros.org/melodic/api/std_msgs/html/msg/Header.html
@@ -50,4 +53,10 @@ class Header(ROSmsg):
     def __init__(self, seq=0, stamp=Time(), frame_id='/world'):
         self.seq = seq
         self.stamp = stamp
-        self.frame_id = frame_id
\ No newline at end of file
+        self.frame_id = frame_id
+
+class String(ROSmsg):
+    """http://docs.ros.org/api/std_msgs/html/msg/String.html
+    """
+    def __init__(self, data=''):
+        self.data = data
