@@ -141,7 +141,7 @@ class MoveItPlanner(PlannerBackend):
                                        attempts=attempts)
 
         def convert_to_positions(response):
-            callback(response.solution.joint_state.position)
+            callback((response.solution.joint_state.position, response.solution.joint_state.name))
 
         self.GET_POSITION_IK(self, (ik_request, ), convert_to_positions, errback)
 
@@ -161,18 +161,23 @@ class MoveItPlanner(PlannerBackend):
         self.GET_POSITION_FK(self, (header, fk_link_names,
                                     robot_state), convert_to_frame, errback)
 
-    def plan_cartesian_motion_async(self, callback, errback, frames, base_link,
-                                    ee_link, group, joint_names, joint_types,
-                                    start_configuration, max_step, jump_threshold,
+    def plan_cartesian_motion_async(self, callback, errback,
+                                    robot, frames, start_configuration,
+                                    group, max_step, jump_threshold,
                                     avoid_collisions, path_constraints,
                                     attached_collision_meshes):
         """Asynchronous handler of MoveIt cartesian motion planner service."""
+        base_link = robot.get_base_link_name(group)
+        ee_link = robot.get_end_effector_link_name(group)
+
+        joint_names = robot.get_configurable_joint_names(group)
         header = Header(frame_id=base_link)
         waypoints = [Pose.from_frame(frame) for frame in frames]
-        joint_state = JointState(
-            header=header, name=joint_names, position=start_configuration.values)
-        start_state = RobotState(
-            joint_state, MultiDOFJointState(header=header))
+        joint_state = JointState(header=header,
+                                 name=joint_names,
+                                 position=start_configuration.values)
+        start_state = RobotState(joint_state, MultiDOFJointState(header=header))
+
         if attached_collision_meshes:
             for acm in attached_collision_meshes:
                 aco = AttachedCollisionObject.from_attached_collision_mesh(acm)
@@ -189,21 +194,30 @@ class MoveItPlanner(PlannerBackend):
                        path_constraints=path_constraints)
 
         def convert_to_trajectory(response):
-            trajectory = JointTrajectory()
-            trajectory.source_message = response
-            trajectory.fraction = response.fraction
-            trajectory.joint_names = response.solution.joint_trajectory.joint_names
-            trajectory.points = convert_trajectory_points(response.solution.joint_trajectory.points, joint_types)
-            trajectory.start_configuration = Configuration(response.start_state.joint_state.position, start_configuration.types)
+            try:
+                trajectory = JointTrajectory()
+                trajectory.source_message = response
+                trajectory.fraction = response.fraction
+                trajectory.joint_names = response.solution.joint_trajectory.joint_names
 
-            callback(trajectory)
+                joint_types = robot.get_joint_types_by_names(trajectory.joint_names)
+                trajectory.points = convert_trajectory_points(
+                    response.solution.joint_trajectory.points, joint_types)
+
+                start_state = response.start_state.joint_state
+                start_state_types = robot.get_joint_types_by_names(start_state.name)
+                trajectory.start_configuration = Configuration(start_state.position, start_state_types)
+
+                callback(trajectory)
+
+            except Exception as e:
+                errback(e)
 
         self.GET_CARTESIAN_PATH(self, request, convert_to_trajectory, errback)
 
-    def plan_motion_async(self, callback, errback, goal_constraints, base_link,
-                          ee_link, group, joint_names, joint_types,
-                          start_configuration, path_constraints=None,
-                          trajectory_constraints=None,
+    def plan_motion_async(self, callback, errback,
+                          robot, goal_constraints, start_configuration, group,
+                          path_constraints=None, trajectory_constraints=None,
                           planner_id='', num_planning_attempts=8,
                           allowed_planning_time=2.,
                           max_velocity_scaling_factor=1.,
@@ -214,6 +228,8 @@ class MoveItPlanner(PlannerBackend):
 
         # http://docs.ros.org/jade/api/moveit_core/html/utils_8cpp_source.html
         # TODO: if list of frames (goals) => receive multiple solutions?
+        base_link = robot.get_base_link_name(group)
+        joint_names = robot.get_configurable_joint_names(group)
 
         header = Header(frame_id=base_link)
         joint_state = JointState(
@@ -275,10 +291,16 @@ class MoveItPlanner(PlannerBackend):
             trajectory.source_message = response
             trajectory.fraction = 1.
             trajectory.joint_names = response.trajectory.joint_trajectory.joint_names
-            trajectory.points = convert_trajectory_points(response.trajectory.joint_trajectory.points, joint_types)
-            trajectory.start_configuration = Configuration(response.trajectory_start.joint_state.position, start_configuration.types)
             trajectory.planning_time = response.planning_time
 
+            joint_types = robot.get_joint_types_by_names(trajectory.joint_names)
+            trajectory.points = convert_trajectory_points(
+                response.trajectory.joint_trajectory.points, joint_types)
+
+            start_state = response.trajectory_start.joint_state
+            start_state_types = robot.get_joint_types_by_names(start_state.name)
+            trajectory.start_configuration = Configuration(start_state.position, start_state_types)
+
             callback(trajectory)
 
         self.GET_MOTION_PLAN(self, request, convert_to_trajectory, errback)
