@@ -8,23 +8,56 @@ compas_fab.robots
 This package contains classes for robot modeling and they are used by the
 simulation, planning and execution backends to exchange information.
 
-Classes
---------
+Main classes
+------------
 
 .. autosummary::
     :toctree: generated/
     :nosignatures:
 
-    Configuration
-    PathPlan
     Robot
     RobotSemantics
-    RosFileServerLoader
+    Configuration
+    Duration
+
+Path planning
+-------------
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    JointTrajectory
+    JointTrajectoryPoint
+    PathPlan
+
+Planning scene
+--------------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    AttachedCollisionMesh
+    CollisionMesh
+    PlanningScene
+
+Constraints
+-----------
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    BoundingVolume
+    Constraint
+    JointConstraint
+    OrientationConstraint
+    PositionConstraint
 
 Unit conversion
 ---------------
 
-The unit systems most commonly used in **compas_fab** are **meters** and **radians**.
+The unit systems most commonly used in **COMPAS FAB** are **meters** and **radians**.
 The following functions help with converting units from one system to the other.
 
 .. autosummary::
@@ -37,17 +70,13 @@ The following functions help with converting units from one system to the other.
 """
 
 from .configuration import *
+from .constraints import *
 from .path_plan import *
+from .planning_scene import *
 from .units import *
 from .robot import *
 from .semantics import *
-from .ros_fileserver_loader import *
+from .time_ import *
+from .trajectory import *
 
-from .configuration import __all__ as a
-from .path_plan import __all__ as b
-from .units import __all__ as c
-from .robot import __all__ as d
-from .semantics import __all__ as e
-from .ros_fileserver_loader import __all__ as f
-
-__all__ = a + b + c + d + e + f
+__all__ = [name for name in dir() if not name.startswith('_')]
